@@ -9,10 +9,6 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from . import graph
-from . import resource
 from . import user
 
-from .graph import *
-from .resource import *
 from .user import *
\ No newline at end of file
