@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from core.resource import Resource
+from semantyk.core.resource import Resource
 from rdflib import URIRef
 
 class User(Resource):
