@@ -187,10 +187,10 @@ class Graph(Resource):
             (s and _s == s) or \
             (p and _p == p) or \
             (o and _o == o):
-                if not resources:resources.add(Resource(dictionary = {str(p): {o}}, uri = _s))
+                if not resources:resources.add(Resource(dictionary = {str(_p): {_o}}, uri = _s))
                 for resource in resources:
                     if _s == resource.uri:
-                        resource.add_value(str(_p), str(o))
+                        resource.add_value(str(_p), str(_o))
         return resources
     resources = property(to_resources)
 
@@ -223,4 +223,4 @@ class Graph(Resource):
         return result
 
 g = Graph(triples = {(SMTK.subject, SMTK.predicate, SMTK.object)})
-print(g.to_resources())
\ No newline at end of file
+print(list(g.resources)[0])
\ No newline at end of file
