@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from core.graph import Graph
+from semantyk.core.graph import Graph
 
 class Model(Graph):
     def __init__(self, id:str, triples:set = None):
